@@ -25,7 +25,7 @@ class WappDriver():
         self.whatsapp_web_url = _var['whatsapp_web_url']
         self.mainScreenLOaded = _var['mainScreenLOaded']
         self.searchSelector = _var['searchSelector']
-        self.personLoaded = _var['personLoaded']
+        # self.personLoaded = _var['personLoaded'] # currently obsolete
         self.mBox = _var['mBox']
 
         # the webdriver waits for an element to be detected on screen on until timeout
@@ -82,16 +82,23 @@ class WappDriver():
 
         try:
             # checking whether new person is loaded or not
-            personLoaded = self.personLoaded.replace("{name}", name)
-            person = WebDriverWait(self.driver, self.timeout).until(expCond.presence_of_element_located(
-                (By.XPATH, personLoaded)))
+            # personLoaded = self.personLoaded.replace("{name}", name)
+            # print(personLoaded)
 
+            person = WebDriverWait(self.driver, self.timeout).until(expCond.presence_of_element_located(
+                (By.XPATH, f'//*[@title="{name}"]')))
+
+            # person = driver.find_element_by_xpath(f'//*[@title="{name}"]')
+            # print(person)
             person.click()
             return True
 
         except Exception as error:
             message = f"""{name} not loaded, MAY BE NOT IN YOUR CONTACTS , 
-                If you are sure {name} is in your contacts, Try checking internet connection """
+                If you are sure {name} is in your contacts, Try checking internet connection
+                
+               OR  May be some other problem ...  """
+               
             convey(error, message)
 
             search_box.send_keys((Keys.BACKSPACE)*len(name))
